<?php

namespace Drupal\mail_box_management\Form;

use Drupal\Core\Messenger\MessengerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\mail_box_management\Plugin\ConfigurationHelper;

/**
 *
 */
class ConfigurationForm extends FormBase {

  public function __construct(
    private readonly ConfigurationHelper $configuration_helper,
    MessengerInterface $messenger,
  ) {
    $this->messenger = $messenger;
  }

  /**
   *
   */
  public static function create(ContainerInterface $container): ConfigurationForm|static {
    return new static(
     $container->get('mail_box_management.config'),
     $container->get('messenger')
    );
  }

  /**
   *
   */
  public function getFormId(): string {
    return 'mail_box_management_configuration_form';
  }

  /**
   *
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {

    $form['form_title'] = [
      '#markup' => '<h1>Mailbox Configuration Form</h1>',
    ];
    $form['connection_type_wrapper'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Connection Type'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    ];
    $form['connection_type_wrapper']['connection_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Connection Type'),
      '#options' => [
        'none' => $this->t('None'),
        'imap' => $this->t('Mailbox IMAP'),
      ],
      '#required' => TRUE,
      '#default_value' => $this->configuration_helper->get('connection_type')?->get('connection_type'),
    ];
    $form['connection_type_wrapper']['connection_type_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Connection Type Title'),
      '#required' => TRUE,
      '#default_value' => $this->configuration_helper->get('connection_type_title')?->get('connection_type_title'),
    ];

    $form['imap_server_wrapper'] = [
      '#type' => 'fieldset',
      '#title' => t('IMAP Server Information'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];
    $form['imap_server_wrapper']['imap_server_host'] = [
      '#type' => 'textfield',
      '#title' => t('Server Host'),
      '#required' => TRUE,
      '#default_value' => $this->configuration_helper->get('imap_server_host')?->get('imap_server_host'),
    ];
    $form['imap_server_wrapper']['imap_server_port'] = [
      '#type' => 'textfield',
      '#title' => t('Server Port'),
      '#required' => TRUE,
      '#default_value' => $this->configuration_helper->get('imap_server_port')?->get('imap_server_port'),
    ];
    $form['imap_server_wrapper']['imap_server_secure'] = [
      '#type' => 'select',
      '#title' => t('Server Secure'),
      '#required' => TRUE,
      '#options' => [
        'ssl' => 'SSL',
        'tls' => 'TLS',
      ],
      '#default_value' => $this->configuration_helper->get('imap_server_secure')?->get('imap_server_secure'),
    ];
    $form['imap_server_wrapper']['imap_server_user_name'] = [
      '#type' => 'textfield',
      '#title' => t('Server Username'),
      '#required' => TRUE,
      '#default_value' => $this->configuration_helper->get('imap_server_user_name')?->get('imap_server_user_name'),
    ];
    $form['imap_server_wrapper']['imap_server_password'] = [
      '#type' => 'password',
      '#title' => t('Server Password'),
      '#required' => TRUE,
      '#default_value' => $this->configuration_helper->get('imap_server_password')?->get('imap_server_password'),
    ];
    $form['imap_server_wrapper']['action'] = [
      '#type' => 'submit',
      '#value' => t('Submit'),
      '#attributes' => [
        'class' => ['button', 'button--primary'],
        'id' => 'mail-box-management-configuration-submit',
      ],
    ];
    return $form;
  }

  /**
   *
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $submitted_data = $form_state->getValues();
    $keys = $this->configuration_helper->getConfigurationsKeys();
    $flag = FALSE;
    foreach ($keys as $key) {
      $list = explode('.', $key);
      $field_name = end($list);
      if ($submitted_value = $submitted_data[$field_name]) {
        $return = $this->configuration_helper->set($key, $submitted_value);
        if ($return) {
          $flag = TRUE;
        }
      }
    }
    if ($flag) {
      $this->messenger->addMessage(t('Configuration successfully saved.'));
      return;
    }

    $this->messenger->addError(t('Failed to save configuration.'));
  }

}
