<?php

namespace Drupal\mail_box_management\Plugin;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 *
 */
class ConfigurationHelper {

  private array $configurations = [
    'mail_box_management.imap_server_host',
    'mail_box_management.imap_server_password',
    'mail_box_management.imap_server_secure',
    'mail_box_management.imap_server_port',
    'mail_box_management.imap_server_user_name',
    'mail_box_management.connection_type',
    'mail_box_management.connection_type_title',
  ];
  private array $configuration_values;

  public function __construct(ConfigFactoryInterface $config_factory) {
    foreach ($this->configurations as $configuration_key) {
      $this->configuration_values[$configuration_key] = $config_factory
        ->getEditable($configuration_key);
    }
  }

  /**
   *
   */
  public function getConfigurationsKeys(): array {
    return $this->configurations;
  }

  /**
   *
   */
  public function getConfigurationValues(): array {
    return $this->configuration_values;
  }

  /**
   *
   */
  public function get(string $configuration_key): Config|NULL {
    if (str_starts_with($configuration_key, 'mail_box_management.')) {
      return $this->configuration_values[$configuration_key] ?? NULL;
    }
    return $this->configuration_values["mail_box_management." . $configuration_key] ?? NULL;
  }

  /**
   *
   */
  public function set(string $configuration_key, $value): Config|bool {
    $config = $this->configuration_values[$configuration_key] ?? NULL;
    if (empty($config)) {
      return FALSE;
    }
    $list = explode('.', $configuration_key);
    $config_storage_key = end($list);
    return $config->set($config_storage_key, $value)->save();
  }

  /**
   *
   */
  public function getConnectionType(): Config|NULL {
    return $this->configuration_values['mail_box_management.connection_type'] ?? NULL;
  }

  /**
   *
   */
  public function getConnectionTypeTitle(): Config|NULL {
    return $this->configuration_values['mail_box_management.connection_type_title'] ?? NULL;
  }

}
