<?php

namespace Drupal\mail_box_management\Plugin;

use Drupal\Component\Render\MarkupInterface;
use Drupal\mail_box_management\Server\Imap\MailBoxStorage;

/**
 *
 */
readonly class ThemeTemplateLoader {

  private ConfigurationHelper $configuration_helper;

  public function __construct() {
    $this->configuration_helper = mail_box_management_service('mail_box_management.config');
  }

  /**
   * @throws \Exception
   */
  public function getThemeTemplateContent(string $template_name, array $variables = []): MarkupInterface|string|null {

    if ($template_name !== "mail-box-management-configuration") {

      $variables['mailbox']['host'] = \Drupal::request()->getSchemeAndHttpHost();
      $variables['mailbox']['path'] = \Drupal::moduleHandler()->getModule('mail_box_management')->getPath();
      $variables['mailbox']['connection'] = [
        'title' => $this->configuration_helper->getConnectionTypeTitle()->get('connection_type_title'),
        'type' => $this->configuration_helper->getConnectionType()->get('connection_type'),
      ];
      /**@var \Drupal\mail_box_management\Server\Imap\ImapConnection $imap*/
      $imap = mail_box_management_service('mail_box_management.imap_connector');
      if(empty($imap->hostname)) {
        return NULL;
      }
      $boxes = new MailBoxStorage($imap);
      $mailboxes = $boxes->getMailboxes();
      $labels = [];

      $mailboxes_statuses = [];
      $headers_content = [];
      if (!empty($mailboxes)) {
        foreach ($mailboxes as $key => $mailbox) {
          $mailboxes_statuses[$key] = $boxes->checkMailboxStatus($mailbox);
          $headers_content[$key] = $boxes->getHeaders($mailbox);
        }
      }
      $variables['mailbox']['imap']['mailboxes_statuses'] = $mailboxes_statuses;
      $variables['mailbox']['imap']['headers_content'] = $headers_content;
      $variables['mailbox']['imap']['active_box']['Inbox'] = TRUE;

      foreach ($mailboxes as $key => $mailbox) {
        $variables['mailbox']['imap']['range'][$key] = $boxes->getTotalRange($mailbox);
      }

      foreach ($mailboxes as $key => $mailbox) {
        if (strpos($mailbox, 'Labels')) {
          $labels[$key] = $mailbox;
          unset($mailboxes[$key]);
        }
      }
      $variables['mailbox']['imap']['mailboxes'] = $mailboxes;
      $variables['mailbox']['imap']['labels'] = $labels;
    }

    // dump($headers_content);
    $elements = [
      '#theme' => $template_name,
      '#title' => '',
      '#content' => $variables,
      '#attached' => [
        'library' => [
          'assets_management',
        ],
      ],
    ];

    /**@var \Drupal\Core\Render\Renderer $render **/
    $render = \Drupal::service('renderer');
    return $render->renderRoot($elements);
  }

}
